@@ -3,7 +3,7 @@
 *                     T h e   A d i e   T e x t   E d i t o r                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2016 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -20,7 +20,6 @@
 ********************************************************************************/
 #include "fx.h"
 #include "fxkeys.h"
-#include <new>
 #include <signal.h>
 #ifndef WIN32
 #include <sys/wait.h>
@@ -31,6 +30,7 @@
 #include "Syntax.h"
 #include "SyntaxParser.h"
 #include "TextWindow.h"
+#include "FindInFiles.h"
 #include "Adie.h"
 #include "icons.h"
 
@@ -40,7 +40,6 @@
   - Manage list of open windows.
 */
 
-
 /*******************************************************************************/
 
 
@@ -121,53 +120,8 @@ Adie::Adie(const FXString& name):FXApp(name){
   }
 
 
-// Get syntax for language name
-Syntax* Adie::getSyntaxByName(const FXString& lang){
-  FXTRACE((10,"Adie::getSyntaxByName(%s)\n",lang.text()));
-  if(!lang.empty()){
-    for(FXint syn=0; syn<syntaxes.no(); syn++){
-      if(syntaxes[syn]->getName()==lang){
-        FXTRACE((10,"syntaxes[%d]: language: %s matched name: %s!\n",syn,syntaxes[syn]->getName().text(),lang.text()));
-        return syntaxes[syn];
-        }
-      }
-    }
-  return NULL;
-  }
-
-
-// Get syntax by matching file patterns
-Syntax* Adie::getSyntaxByPattern(const FXString& file){
-  FXTRACE((10,"Adie::getSyntaxByPattern(%s)\n",file.text()));
-  if(!file.empty()){
-    for(FXint syn=0; syn<syntaxes.no(); syn++){
-      if(syntaxes[syn]->matchFilename(file)){
-        FXTRACE((10,"syntaxes[%d]: language: %s matched file: %s!\n",syn,syntaxes[syn]->getName().text(),file.text()));
-        return syntaxes[syn];
-        }
-      }
-    }
-  return NULL;
-  }
-
-
-// Get syntax by matching file contents
-Syntax* Adie::getSyntaxByContents(const FXString& contents){
-  FXTRACE((10,"Adie::getSyntaxByContents(%s)\n",contents.text()));
-  if(!contents.empty()){
-    for(FXint syn=0; syn<syntaxes.no(); syn++){
-      if(syntaxes[syn]->matchContents(contents)){
-        FXTRACE((10,"syntaxes[%d]: language: %s matched contents: %s!\n",syn,syntaxes[syn]->getName().text(),contents.text()));
-        return syntaxes[syn];
-        }
-      }
-    }
-  return NULL;
-  }
-
-
 // Close all windows
-long Adie::onCmdCloseAll(FXObject*,FXSelector,void*){
+long Adie::onCmdCloseAll(FXObject*,FXSelector,void*){      
   while(0<windowlist.no() && windowlist[0]->close(true)){}
   return 1;
   }
@@ -218,7 +172,7 @@ static void printusage(){
 // Print verson info
 static void printversion(){
   fxmessage("A.d.i.e. - ADvanced Interactive Editor %d.%d.%d.\n",VERSION_MAJOR,VERSION_MINOR,VERSION_PATCH);
-  fxmessage("Copyright (C) 2000,2014 Jeroen van der Zijp.  All Rights Reserved.\n\n");
+  fxmessage("Copyright (C) 2000,2016 Jeroen van der Zijp.  All Rights Reserved.\n\n");
   fxmessage("Please visit: http://www.fox-toolkit.org for further information.\n");
   fxmessage("\n");
   fxmessage("This program is free software: you can redistribute it and/or modify\n");
@@ -246,7 +200,7 @@ FXint Adie::start(int argc,char** argv){
   FXint       col=0;
   FXint       arg=1;
 
-  // After init, the registry has been loaded
+  // The registry has been loaded after this
   init(argc,argv);
 
   // Make a tool tip
@@ -258,15 +212,23 @@ FXint Adie::start(int argc,char** argv){
   // Exec path is default for syntax path
   execpath=FXSystem::getExecPath();
 
+  FXTRACE((10,"execpath=%s\n",execpath.text()));
+
   // Get syntax path
   syntaxpaths=reg().readStringEntry("SETTINGS","syntaxpaths",execpath.text());
 
+  FXTRACE((10,"syntaxpaths=%s\n",syntaxpaths.text()));
+
   // Hunt for the syntax file
   syntaxfile=FXPath::search(syntaxpaths,"Adie.stx");
 
+  FXTRACE((10,"syntaxfile=%s\n",syntaxfile.text()));
+
   // Get icon search path
   iconpath=reg().readStringEntry("SETTINGS","iconpath",FXIconCache::defaultIconPath);
 
+  FXTRACE((10,"iconpath=%s\n",iconpath.text()));
+
   // Change icon search path
   associations->setIconPath(iconpath);
 
@@ -331,8 +293,9 @@ FXint Adie::start(int argc,char** argv){
 
     // Start in directory with empty untitled file
     if(FXStat::isDirectory(file)){
-      file=FXPath::absolute(file,"untitled");
+      file=unique(file);
       window->setFilename(file);
+      window->setFilenameSet(false);
       window->setBrowserCurrentFile(file);
       }
 
@@ -348,6 +311,7 @@ FXint Adie::start(int argc,char** argv){
     // Start in directory with empty or inaccessible file
     else{
       window->setFilename(file);
+      window->setFilenameSet(false);    // Prompt for name when saving
       window->determineSyntax();
       window->setBrowserCurrentFile(file);
       window->determineSyntax();
@@ -370,6 +334,7 @@ FXint Adie::start(int argc,char** argv){
     // Compute absolute path
     file=FXPath::absolute("untitled");
     window->setFilename(file);
+    window->setFilenameSet(false);
     window->setBrowserCurrentFile(file);
 
     // Override language mode?
@@ -382,6 +347,124 @@ FXint Adie::start(int argc,char** argv){
   return run();
   }
 
+
+// Generate unique name from given path
+FXString Adie::unique(const FXString& path) const {
+  FXString name="untitled";
+  FXString file;
+  for(FXint i=1; i<2147483647; i++){
+    file=FXPath::absolute(path,name);
+    if(!findWindow(file)) break;
+    name.format("untitled%d",i);
+    }
+  return file;
+  }
+
+
+// Find an as yet untitled, unedited window
+TextWindow *Adie::findUnused() const {
+  for(FXint w=0; w<windowlist.no(); w++){
+    if(!windowlist[w]->isFilenameSet() && !windowlist[w]->isModified()){
+      return windowlist[w];
+      }
+    }
+  return NULL;
+  }
+
+
+// Find window, if any, currently editing the given file
+TextWindow* Adie::findWindow(const FXString& file) const {
+  for(FXint w=0; w<windowlist.no(); w++){
+    if(windowlist[w]->getFilename()==file){
+      return windowlist[w];
+      }
+    }
+  return NULL;
+  }
+
+
+// Open file and jump to line, or just jump to line if already open
+TextWindow* Adie::openFileWindow(const FXString& file,FXint lineno,FXint column){
+  TextWindow *window=NULL;
+
+  FXTRACE((1,"Adie::openFileWindow(%s,%d,%d)\n",file.text(),lineno,column));
+
+  // See if we already have this file
+  window=findWindow(file);
+  if(!window){
+
+    // Create new one if no unused windows
+    window=findUnused();
+    if(!window){
+      window=new TextWindow(this);
+      window->create();
+      }
+
+    // Load the file
+    if(window->loadFile(file)){
+      window->clearBookmarks();
+      window->readBookmarks(file);
+      window->readView(file);
+      window->determineSyntax();
+      }
+    }
+
+  // Switch line number only
+  if(lineno){
+    window->visitLine(lineno,column);
+    }
+
+  // Bring up the window
+  window->raise();
+  window->setFocus();
+  return window;
+  }
+
+
+// Get syntax for language name
+Syntax* Adie::getSyntaxByName(const FXString& lang){
+  FXTRACE((10,"Adie::getSyntaxByName(%s)\n",lang.text()));
+  if(!lang.empty()){
+    for(FXint syn=0; syn<syntaxes.no(); syn++){
+      if(syntaxes[syn]->getName()==lang){
+        FXTRACE((10,"syntaxes[%d]: language: %s matched name: %s!\n",syn,syntaxes[syn]->getName().text(),lang.text()));
+        return syntaxes[syn];
+        }
+      }
+    }
+  return NULL;
+  }
+
+
+// Get syntax by matching file patterns
+Syntax* Adie::getSyntaxByPattern(const FXString& file){
+  FXTRACE((10,"Adie::getSyntaxByPattern(%s)\n",file.text()));
+  if(!file.empty()){
+    for(FXint syn=0; syn<syntaxes.no(); syn++){
+      if(syntaxes[syn]->matchFilename(file)){
+        FXTRACE((10,"syntaxes[%d]: language: %s matched file: %s!\n",syn,syntaxes[syn]->getName().text(),file.text()));
+        return syntaxes[syn];
+        }
+      }
+    }
+  return NULL;
+  }
+
+
+// Get syntax by matching file contents
+Syntax* Adie::getSyntaxByContents(const FXString& contents){
+  FXTRACE((10,"Adie::getSyntaxByContents(%s)\n",contents.text()));
+  if(!contents.empty()){
+    for(FXint syn=0; syn<syntaxes.no(); syn++){
+      if(syntaxes[syn]->matchContents(contents)){
+        FXTRACE((10,"syntaxes[%d]: language: %s matched contents: %s!\n",syn,syntaxes[syn]->getName().text(),contents.text()));
+        return syntaxes[syn];
+        }
+      }
+    }
+  return NULL;
+  }
+
 /*******************************************************************************/
 
 // Clean up the mess
