@@ -3,7 +3,7 @@
 *                     T h e   A d i e   T e x t   E d i t o r                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2016 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -39,12 +39,12 @@ class Adie : public FXApp {
   FXDECLARE(Adie)
   friend class TextWindow;
 protected:
-  TextWindowList      windowlist;                   // Window list
-  FXFileAssociations *associations;                 // File association table
-  SyntaxList          syntaxes;                     // List of syntax patterns
-  FXString            syntaxpaths;                  // Where to look for syntax file
-  FXIcon             *bigicon;                      // Big application icon
-  FXIcon             *smallicon;                    // Small application icon
+  TextWindowList      windowlist;               // Window list
+  FXFileAssociations *associations;             // File association table
+  SyntaxList          syntaxes;                 // List of syntax patterns
+  FXString            syntaxpaths;              // Where to look for syntax file
+  FXIcon             *bigicon;                  // Big application icon
+  FXIcon             *smallicon;                // Small application icon
   FXIcon             *newicon;
   FXIcon             *reloadicon;
   FXIcon             *openicon;
@@ -103,6 +103,18 @@ public:
   // Run the application
   FXint start(int argc,char** argv);
 
+  // Generate unique name from given path
+  FXString unique(const FXString& path) const;
+
+  // Find an as yet untitled, unedited window
+  TextWindow* findUnused() const;
+
+  // Find window, if any, currently editing the given file
+  TextWindow* findWindow(const FXString& file) const;
+
+  // Open file and jump to line, or just jump to line/column if already open
+  TextWindow* openFileWindow(const FXString& file,FXint lineno=0,FXint column=0);
+
   // Get syntax for language name
   Syntax* getSyntaxByName(const FXString& lang);
 
