@@ -3,7 +3,7 @@
 *                            H e l p   W i n d o w                              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2016 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -26,7 +26,7 @@ class Adie;
 
 
 /// Online help dialog box
-class HelpWindow : public FXDialogBox {
+class HelpWindow : public FXTopWindow {
   FXDECLARE(HelpWindow)
 protected:
   FXText *helptext;         // Help display
