@@ -3,7 +3,7 @@
 *                        P r e f e r e n c e s   D i a l o g                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2016 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -52,11 +52,11 @@ public:
   // Owner is text window
   Adie* getApp() const { return (Adie*)FXDialogBox::getApp(); }
 
-  // Set filename patterns
-  void setPatterns(const FXString& patterns);
+  // Set list of filename patterns
+  void setPatternList(const FXString& patterns);
 
-  // Get filename patterns
-  FXString getPatterns() const;
+  // Get list of filename patterns
+  FXString getPatternList() const;
 
   // Set language syntax
   void setSyntax(Syntax* syn);
