@@ -3,7 +3,7 @@
 *                      E x p r e s s i o n   E v a l u a t o r                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2016 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,6 +21,7 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxmath.h"
 #include "fxascii.h"
 #include "fxunicode.h"
 #include "FXArray.h"
@@ -71,63 +72,63 @@ namespace {
 
 // Tokens
 enum {
-  TK_EOF        = 0,
-  TK_INT        = 1,
-  TK_INT_HEX    = 2,
-  TK_INT_BIN    = 3,
-  TK_INT_OCT    = 4,
-  TK_REAL       = 5,
-  TK_PLUS       = 6,
-  TK_MINUS      = 7,
-  TK_TIMES      = 8,
-  TK_DIVIDE     = 9,
-  TK_MODULO     = 10,
-  TK_POWER      = 11,
-  TK_LPAR       = 12,
-  TK_RPAR       = 13,
-  TK_LESS       = 14,
-  TK_GREATER    = 15,
-  TK_LESSEQ     = 16,
-  TK_GREATEREQ  = 17,
-  TK_EQUAL      = 18,
-  TK_NOTEQUAL   = 19,
-  TK_AND        = 20,
-  TK_OR         = 21,
-  TK_XOR        = 22,
-  TK_NOT        = 23,
-  TK_SHIFTLEFT  = 24,
-  TK_SHIFTRIGHT = 25,
-  TK_COMMA      = 26,
-  TK_QUEST      = 27,
-  TK_COLON      = 28,
-  TK_ERROR      = 29,
-  TK_PI         = 2585,
-  TK_EULER      = 69,
-  TK_RTOD       = 3005613,
-  TK_DTOR       = 2389741,
-  TK_ABS        = 108848,
-  TK_ACOS       = 3592862,
-  TK_ACOSH      = 118564406,
-  TK_ASIN       = 3610325,
-  TK_ASINH      = 119140637,
-  TK_ATAN       = 3615258,
-  TK_ATANH      = 119303474,
-  TK_CEIL       = 3523203,
-  TK_COS        = 107103,
-  TK_COSH       = 3534423,
-  TK_EXP        = 114029,
-  TK_FLOOR      = 122360152,
-  TK_LOG        = 114052,
-  TK_LOG10      = 124204261,
-  TK_SIN        = 124308,
-  TK_SINH       = 4102268,
+  TK_EOF        = 0U,
+  TK_INT        = 1U,
+  TK_INT_HEX    = 2U,
+  TK_INT_BIN    = 3U,
+  TK_INT_OCT    = 4U,
+  TK_REAL       = 5U,
+  TK_PLUS       = 6U,
+  TK_MINUS      = 7U,
+  TK_TIMES      = 8U,
+  TK_DIVIDE     = 9U,
+  TK_MODULO     = 10U,
+  TK_POWER      = 11U,
+  TK_LPAR       = 12U,
+  TK_RPAR       = 13U,
+  TK_LESS       = 14U,
+  TK_GREATER    = 15U,
+  TK_LESSEQ     = 16U,
+  TK_GREATEREQ  = 17U,
+  TK_EQUAL      = 18U,
+  TK_NOTEQUAL   = 19U,
+  TK_AND        = 20U,
+  TK_OR         = 21U,
+  TK_XOR        = 22U,
+  TK_NOT        = 23U,
+  TK_SHIFTLEFT  = 24U,
+  TK_SHIFTRIGHT = 25U,
+  TK_COMMA      = 26U,
+  TK_QUEST      = 27U,
+  TK_COLON      = 28U,
+  TK_ERROR      = 29U,
+  TK_PI         = 2585U,
+  TK_EULER      = 69U,
+  TK_RTOD       = 3005613U,
+  TK_DTOR       = 2389741U,
+  TK_ABS        = 108848U,
+  TK_ACOS       = 3592862U,
+  TK_ACOSH      = 118564406U,
+  TK_ASIN       = 3610325U,
+  TK_ASINH      = 119140637U,
+  TK_ATAN       = 3615258U,
+  TK_ATANH      = 119303474U,
+  TK_CEIL       = 3523203U,
+  TK_COS        = 107103U,
+  TK_COSH       = 3534423U,
+  TK_EXP        = 114029U,
+  TK_FLOOR      = 122360152U,
+  TK_LOG        = 114052U,
+  TK_LOG10      = 124204261U,
+  TK_SIN        = 124308U,
+  TK_SINH       = 4102268U,
   TK_SQRT       = 4076772,
-  TK_TAN        = 123227,
-  TK_TANH       = 4066515,
-  TK_MAX        = 121748,
-  TK_MIN        = 121482,
-  TK_POW        = 119176,
-  TK_ATAN2      = 119303528
+  TK_TAN        = 123227U,
+  TK_TANH       = 4066515U,
+  TK_MAX        = 121748U,
+  TK_MIN        = 121482U,
+  TK_POW        = 119176U,
+  TK_ATAN2      = 119303528U
   };
 
 
@@ -204,7 +205,7 @@ public:
 
   // Return size of generated code
   FXival size() const { return pc-code; }
-  
+
   // Get token
   void gettok();
 
@@ -454,19 +455,19 @@ FXExpression::Error FXCompile::element(){
       break;
     case TK_PI:
       opcode(OP_NUM);
-      number(3.1415926535897932384626433832795029);
+      number(PI);
       break;
     case TK_EULER:
       opcode(OP_NUM);
-      number(2.7182818284590452353602874713526625);
+      number(EULER);
       break;
     case TK_RTOD:
       opcode(OP_NUM);
-      number(57.295779513082320876798154814);
+      number(RTOD);
       break;
     case TK_DTOR:
       opcode(OP_NUM);
-      number(0.0174532925199432957692369077);
+      number(DTOR);
       break;
     case TK_MAX:
       op=OP_MAX;
@@ -741,9 +742,9 @@ void FXCompile::gettok(){
       default:
         token=TK_ERROR;
         if(Ascii::isLetter(*tail)){
-          token=*tail++;
+          token=(FXuchar)*tail++;
           while(Ascii::isAlphaNumeric(*tail)){
-            token=((token<<5)+token)^*tail++;
+            token=((token<<5)+token) ^ (FXuchar)*tail++;
             }
           }
         return;
@@ -779,7 +780,7 @@ FXuchar* FXCompile::offset(FXshort n){
 FXuchar* FXCompile::number(FXdouble n){
   register FXuchar* result=pc;
   if(code){
-#if defined(__i386__) || defined(__x86_64__) 
+#if defined(__i386__) || defined(__x86_64__)
     ((FXdouble*)pc)[0]=n;
 #else
     pc[0]=((const FXuchar*)&n)[0];
@@ -894,7 +895,7 @@ FXExpression::Error FXExpression::parse(const FXchar* expression,const FXchar* v
 
       // Allocate new code
       if(allocElms(prog,cs.size())){
-        
+
         // Create compile engine
         FXCompile gs(prog,expression,variables);
 
@@ -906,7 +907,7 @@ FXExpression::Error FXExpression::parse(const FXchar* expression,const FXchar* v
 
           // Install new program
           code=prog;
-          
+
 #ifdef EXPRDEBUG
           if(fxTraceLevel>100) dump(code);
 #endif
@@ -915,7 +916,7 @@ FXExpression::Error FXExpression::parse(const FXchar* expression,const FXchar* v
           return ErrOK;
           }
         freeElms(prog);
-        }        
+        }
       }
     }
   return err;
@@ -947,34 +948,28 @@ FXdouble FXExpression::evaluate(const FXdouble *args) const {
       case OP_VAR:   *++sp=args[*pc++]; break;
       case OP_NOT:   *sp=(FXdouble)(~((FXlong)*sp)); break;
       case OP_NEG:   *sp=-*sp; break;
-      case OP_SIN:   *sp=sin(*sp); break;
-      case OP_COS:   *sp=cos(*sp); break;
-      case OP_TAN:   *sp=tan(*sp); break;
-      case OP_ASIN:  *sp=asin(*sp); break;
-      case OP_ACOS:  *sp=acos(*sp); break;
-      case OP_ATAN:  *sp=atan(*sp); break;
-      case OP_SINH:  *sp=sinh(*sp); break;
-      case OP_COSH:  *sp=cosh(*sp); break;
-      case OP_TANH:  *sp=tanh(*sp); break;
-#if defined(WIN32) || defined(__minix)
-      case OP_ASINH: *sp=log(*sp + sqrt(*sp * *sp + 1.0)); break;
-      case OP_ACOSH: *sp=log(*sp + sqrt(*sp * *sp - 1.0)); break;
-      case OP_ATANH: *sp=0.5 * log((1.0 + *sp)/(1.0 - *sp)); break;
-#else
-      case OP_ASINH: *sp=asinh(*sp); break;
-      case OP_ACOSH: *sp=acosh(*sp); break;
-      case OP_ATANH: *sp=atanh(*sp); break;
-#endif
-      case OP_SQRT:  *sp=sqrt(*sp); break;
-      case OP_ABS:   *sp=fabs(*sp); break;
-      case OP_CEIL:  *sp=ceil(*sp); break;
-      case OP_FLOOR: *sp=floor(*sp); break;
-      case OP_EXP:   *sp=exp(*sp); break;
-      case OP_LOG:   *sp=log(*sp); break;
-      case OP_LOG10: *sp=log10(*sp); break;
+      case OP_SIN:   *sp=Math::sin(*sp); break;
+      case OP_COS:   *sp=Math::cos(*sp); break;
+      case OP_TAN:   *sp=Math::tan(*sp); break;
+      case OP_ASIN:  *sp=Math::asin(*sp); break;
+      case OP_ACOS:  *sp=Math::acos(*sp); break;
+      case OP_ATAN:  *sp=Math::atan(*sp); break;
+      case OP_SINH:  *sp=Math::sinh(*sp); break;
+      case OP_COSH:  *sp=Math::cosh(*sp); break;
+      case OP_TANH:  *sp=Math::tanh(*sp); break;
+      case OP_ASINH: *sp=Math::asinh(*sp); break;
+      case OP_ACOSH: *sp=Math::acosh(*sp); break;
+      case OP_ATANH: *sp=Math::atanh(*sp); break;
+      case OP_SQRT:  *sp=Math::sqrt(*sp); break;
+      case OP_ABS:   *sp=Math::fabs(*sp); break;
+      case OP_CEIL:  *sp=Math::ceil(*sp); break;
+      case OP_FLOOR: *sp=Math::floor(*sp); break;
+      case OP_EXP:   *sp=Math::exp(*sp); break;
+      case OP_LOG:   *sp=Math::log(*sp); break;
+      case OP_LOG10: *sp=Math::log10(*sp); break;
       case OP_MUL:   *(sp-1)=*(sp-1) * *sp; --sp; break;
       case OP_DIV:   *(sp-1)=*(sp-1) / *sp; --sp; break;
-      case OP_MOD:   *(sp-1)=fmod(*(sp-1),*sp); --sp; break;
+      case OP_MOD:   *(sp-1)=Math::fmod(*(sp-1),*sp); --sp; break;
       case OP_ADD:   *(sp-1)=*(sp-1) + *sp; --sp; break;
       case OP_SUB:   *(sp-1)=*(sp-1) - *sp; --sp; break;
       case OP_AND:   *(sp-1)=(FXdouble)(((FXlong)*(sp-1)) & ((FXlong)*sp)); --sp; break;
@@ -988,10 +983,10 @@ FXdouble FXExpression::evaluate(const FXdouble *args) const {
       case OP_GE:    *(sp-1)=(FXdouble)(*(sp-1) >= *sp); --sp; break;
       case OP_EQ:    *(sp-1)=(FXdouble)(*(sp-1) == *sp); --sp; break;
       case OP_NE:    *(sp-1)=(FXdouble)(*(sp-1) != *sp); --sp; break;
-      case OP_POW:   *(sp-1)=pow(*(sp-1),*sp); --sp; break;
-      case OP_MAX:   *(sp-1)=FXMAX(*(sp-1),*sp); --sp; break;
-      case OP_MIN:   *(sp-1)=FXMIN(*(sp-1),*sp); --sp; break;
-      case OP_ATAN2: *(sp-1)=atan2(*(sp-1),*sp); --sp; break;
+      case OP_POW:   *(sp-1)=Math::pow(*(sp-1),*sp); --sp; break;
+      case OP_MAX:   *(sp-1)=Math::fmax(*(sp-1),*sp); --sp; break;
+      case OP_MIN:   *(sp-1)=Math::fmin(*(sp-1),*sp); --sp; break;
+      case OP_ATAN2: *(sp-1)=Math::atan2(*(sp-1),*sp); --sp; break;
       }
     }
   return 0.0;
